from cpl_core.configuration import ConfigurationABC
from cpl_core.dependency_injection import ServiceCollectionABC
from cpl_core.environment import ApplicationEnvironmentABC
from cpl_discord.service.discord_collection_abc import DiscordCollectionABC

from bot_core.abc.module_abc import ModuleABC
from bot_core.configuration.feature_flags_enum import FeatureFlagsEnum
from bot_data.service.seeder_service import SeederService
from bot_graphql.abc.query_abc import QueryABC
from bot_graphql.graphql_service import GraphQLService
from bot_graphql.mutation import Mutation
from bot_graphql.mutations.level_mutation import LevelMutation
from bot_graphql.queries.auto_role_query import AutoRoleQuery
from bot_graphql.queries.auto_role_rule_query import AutoRoleRuleQuery
from bot_graphql.queries.client_query import ClientQuery
from bot_graphql.queries.level_query import LevelQuery
from bot_graphql.queries.server_query import ServerQuery
from bot_graphql.queries.user_joined_server_query import UserJoinedServerQuery
from bot_graphql.queries.user_joined_voice_channel_query import UserJoinedVoiceChannelQuery
from bot_graphql.queries.user_query import UserQuery
from bot_graphql.query import Query
from bot_graphql.schema import Schema


class GraphQLModule(ModuleABC):
    def __init__(self, dc: DiscordCollectionABC):
        ModuleABC.__init__(self, dc, FeatureFlagsEnum.data_module)

    def configure_configuration(self, config: ConfigurationABC, env: ApplicationEnvironmentABC):
        pass

    def configure_services(self, services: ServiceCollectionABC, env: ApplicationEnvironmentABC):
        services.add_singleton(Schema)
        services.add_singleton(GraphQLService)
        services.add_singleton(Query)
        services.add_singleton(Mutation)
        services.add_transient(QueryABC, ServerQuery)
        services.add_transient(QueryABC, LevelQuery)
        services.add_transient(QueryABC, LevelMutation)
        services.add_transient(QueryABC, ClientQuery)
        services.add_transient(QueryABC, UserQuery)
        services.add_transient(QueryABC, UserJoinedServerQuery)
        services.add_transient(QueryABC, UserJoinedVoiceChannelQuery)
        services.add_transient(QueryABC, AutoRoleQuery)
        services.add_transient(QueryABC, AutoRoleRuleQuery)

        services.add_transient(SeederService)
